# Table of Contents

- [migrating-from-fact-sheets-rest-api-to-graphql-api](<./migrating-from-fact-sheets-rest-api-to-graphql-api.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
  - [Table of Contents](<./SAP-LeanIX/Table-of-Contents.md>)
- [Migrating from the Fact Sheets REST API to the GraphQL API](<./Migrating-from-the-Fact-Sheets-REST-API-to-the-GraphQL-API.md>)
  - [Overview](<./Migrating-from-the-Fact-Sheets-REST-API-to-the-GraphQL-API/Overview.md>)
  - [Before You Start](<./Migrating-from-the-Fact-Sheets-REST-API-to-the-GraphQL-API/Before-You-Start.md>)
  - [Get All Fact Sheets](<./Migrating-from-the-Fact-Sheets-REST-API-to-the-GraphQL-API/Get-All-Fact-Sheets.md>)
  - [Get a Fact Sheet Hierarchy by Root ID](<./Migrating-from-the-Fact-Sheets-REST-API-to-the-GraphQL-API/Get-a-Fact-Sheet-Hierarchy-by-Root-ID.md>)
  - [Get a Fact Sheet by ID](<./Migrating-from-the-Fact-Sheets-REST-API-to-the-GraphQL-API/Get-a-Fact-Sheet-by-ID.md>)
  - [Get All Relations of a Fact Sheet](<./Migrating-from-the-Fact-Sheets-REST-API-to-the-GraphQL-API/Get-All-Relations-of-a-Fact-Sheet.md>)
  - [Create a Fact Sheet](<./Migrating-from-the-Fact-Sheets-REST-API-to-the-GraphQL-API/Create-a-Fact-Sheet.md>)
  - [Update a Fact Sheet](<./Migrating-from-the-Fact-Sheets-REST-API-to-the-GraphQL-API/Update-a-Fact-Sheet.md>)
  - [Archive a Fact Sheet](<./Migrating-from-the-Fact-Sheets-REST-API-to-the-GraphQL-API/Archive-a-Fact-Sheet.md>)
  - [Create a Fact Sheet Relation](<./Migrating-from-the-Fact-Sheets-REST-API-to-the-GraphQL-API/Create-a-Fact-Sheet-Relation.md>)
  - [Update a Fact Sheet Relation](<./Migrating-from-the-Fact-Sheets-REST-API-to-the-GraphQL-API/Update-a-Fact-Sheet-Relation.md>)
  - [Delete a Fact Sheet Relation](<./Migrating-from-the-Fact-Sheets-REST-API-to-the-GraphQL-API/Delete-a-Fact-Sheet-Relation.md>)
  - [Was this page helpful?](<./Migrating-from-the-Fact-Sheets-REST-API-to-the-GraphQL-API/Was-this-page-helpful.md>)
